@@ -1,5 +1,5 @@
 package Template::Magic ;
-$VERSION = 1.32 ;
+$VERSION = 1.34 ;
 use AutoLoader 'AUTOLOAD' ;
 
 # This file uses the "Perlish" coding style
@@ -33,7 +33,6 @@ use AutoLoader 'AUTOLOAD' ;
                        
 # predeclaration of autoloaded methods
 ; use subs @autoloaded
-; our %CACHE
 
 ; sub import
    { my ($pkg, $pragma, @subs) = @_
@@ -145,7 +144,7 @@ use AutoLoader 'AUTOLOAD' ;
       ; $$s{_re}{label}          = qr/$S$I*$ID$A$E/s
       ; $$s{_re}{start_label}    = qr/$S($ID)($A)$E/s
       ; $$s{_re}{end_label}      = qr/$S$I($ID)$E/s
-      ; $$s{_re}{include_label}  = qr/$S\bINCLUDE_TEMPLATE\s+($A)$E/s
+      ; $$s{_re}{include_label}  = qr/$S\bINCLUDE_TEMPLATE\b($A)$E/s
       }
    ; wantarray
      ? @{$$s{markers}}
@@ -211,66 +210,63 @@ use AutoLoader 'AUTOLOAD' ;
 ; sub _process
    { my ($s, $args) = @_
    ; $$s{_temp_lookups} = $$args{lookups} if exists $$args{lookups}
-   ; my $z = $s->load( $$args{template} )
+   ; my $t
+   ; if ( $t =  $$args{container_template}
+             || ${$$s{container_template}}[0]
+        )
+      { $$s{_included_template} = $$args{template}
+      }
+     else
+      { $t = $$args{template}
+      }
+   ; my $z = $s->load( $t )
    ; $$z{tm} = $s
    ; $z->content_process($s)
    ; delete $$z{tm} # to avoid tm object caching
-   ; delete @$s{qw|_temp_lookups _NOT_lookup|}
+   ; delete @$s{qw|_included_template _temp_lookups _NOT_lookup|}
    }
 
-
 ; sub load
    { my ($s, $t) = @_
+   ; my $main_zone
    ; if ( not ref $t )
-      { $t = $s->find_file($t) or croak qq(Template file "$t" empty or not found)
-      ; if ( $$s{options}{cache})
-         { my $path = File::Spec->rel2abs($t)
-         ; my $mtime = ( stat($path) )[9]
-         ;  exists $CACHE{$path}             # if it is cached
-         && $mtime > $CACHE{$path}{mtime}    # and old
-         && $s->purge_cache($path)           # purge $path from cache
-         ; unless ( exists $CACHE{$path} )   # if it is not cached
-            { $CACHE{$path}{main_zone} = $s->_parse(IO::Util::slurp $t)
-            ; $CACHE{$path}{mtime}     = $mtime
-            }
-         ; $CACHE{$path}{main_zone}
-         }
-        else
-         { $s->_parse( IO::Util::slurp $t )
+      { $t = $s->find_file($t)
+             or croak qq(Template file "$t" empty or not found)
+      ; if ( $$s{options}{cache} )
+         { $main_zone = IO::Util::_get_parsing_cache('magic_zone', $t)
+         ; return $main_zone if $main_zone
          }
       }
-     elsif ( ref $t eq 'GLOB' )
-      { $s->_parse( IO::Util::slurp $t ) ;
-      }
-     elsif ( ref $t eq 'SCALAR' )
-      { $s->_parse( $t )
-      }
+   ; my $content = ref $t eq 'SCALAR' ? $t : IO::Util::slurp $t
+   ; $main_zone  =  $s->_parse( $content )
+   ; $$s{options}{cache}  &&! ref($t)    # set cache
+     && IO::Util::_set_parsing_cache 'magic_zone', $t, $main_zone
+   ; $main_zone
    }
 
 ; sub purge_cache
-   { my ($s, @paths) = @_
-   ; @paths || return undef %CACHE
-   ; @paths = map { File::Spec->rel2abs($_)
-                  }
-                  @paths
-   ; foreach my $path ( @paths )
-      { delete $CACHE{$path}
-      }
+   { $_[0] = 'magic_zone'
+   ; goto &IO::Util::_purge_parsing_cache
    }
 
 ; sub _parse
    { my ($s, $content_ref) = @_
    ; my $re = $s->_re
-   ; my @temp = map { [ $_
-                      , do {  /$$re{end_label}/     && $1
-                           || /$$re{include_label}/ && $s->load($1)
-                           || /$$re{start_label}/   && { id         => $1
-                                                       , attributes => $2
-                                                       }
-                           }
-                      ]
-                    }
-                    split /($$re{label})/ , $$content_ref
+   ; my @temp
+     = map { [ $_
+             , do {  /$$re{end_label}/     && $1
+                  || /$$re{include_label}/ && do{ (my $t = $1) =~ s/^\s+//
+                                                ; $t
+                                                  ? $s->load($t)
+                                                  : 'CONTAINER_INCLUDE'
+                                                }
+                  || /$$re{start_label}/   && { id         => $1
+                                              , attributes => $2
+                                              }
+                  }
+             ]
+           }
+           split /($$re{label})/ , $$content_ref
    ; for ( my $i  = $#temp                        # find end
          ;    $i >= 0
          ;    $i --
@@ -301,7 +297,7 @@ use AutoLoader 'AUTOLOAD' ;
                                , is_main => 1
                                )
    }
-   
+    
 
 ############################# STANDARD HANDLERS #############################
 
@@ -628,9 +624,9 @@ sub FillInForm # value handler
 
 Template::Magic - Magic merger of runtime values with templates
 
-=head1 VERSION 1.32
+=head1 VERSION 1.34
 
-Included in Template-Magic 1.32 distribution.
+Included in Template-Magic 1.34 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -642,7 +638,7 @@ The latest versions changes are reported in the F<Changes> file in this distribu
 
     Perl version >= 5.6.1
     OOTools      >= 1.52
-    IO::Util     >= 1.26
+    IO::Util     >= 1.42
     File::Spec   >= 0
 
 =item CPAN
@@ -943,14 +939,15 @@ This method accepts any number of I<temporary lookups> elements that could be I<
     $my_block_output = $tm->output( '/path/to/template', \%special_hash );
 
 
-B<Note>: if I<template> is a path, the object will cache it automatically, so Template::Magic will open and parse the template file only the first time or if the file has been modified. If for any reason you don't want the template to be cached, you can use the 'cache / no_cache' L<"options">.
+B<Note>: if I<template> is a path, the object will cache it automatically, so Template::Magic will open and parse the template file only the first time or if the file has been modified. If for any reason you don't want to cache the template structure, you can use the 'cache / no_cache' L<"options">.
 
 =head2 noutput ( arguments )
 
-A named arguments interface for the L<output()|"output ( template [, temporary lookups ] )"> method.
+A named arguments interface for the L<output()|"output ( template [, temporary lookups ] )"> method, which add also the possibility to pass the 'container_template' argument.
 
     $tm->nprint( template => '/path/to/template',
-                 lookups  => [ \%special_hash, 'My::lookups'] ) ;
+                 lookups  => [ \%special_hash, 'My::lookups'],
+                 container_template => '/path/to/container_template') ;
 
 =head2 print ( template [, temporary lookups ] )
 
@@ -970,14 +967,15 @@ This method accepts any number of I<temporary lookups> elements that could be I<
     # this adds some lookups location to the print method 
     $tm->print( '/path/to/template', \%special_hash );
 
-B<Note>: if I<template> is a path, the object will cache it automatically, so Template::Magic will open and parse the template file only the first time or if the file has been modified. If for any reason you don't want the template to be cached, you can use the 'cache / no_cache' L<"options">. I<(see L<"EFFICIENCY">)>.
+B<Note>: if I<template> is a path, the object will cache it automatically, so Template::Magic will open and parse the template file only the first time or if the file has been modified. If for any reason you don't want to cache the template structure, you can use the 'cache / no_cache' L<"options">. I<(see L<"EFFICIENCY">)>.
 
 =head2 nprint ( arguments )
 
-A named arguments interface for the L<print()|"print ( template [, temporary lookups ] )"> method.
+A named arguments interface for the L<print()|"print ( template [, temporary lookups ] )"> method, which add also the possibility to pass the 'container_template' argument.
 
     $tm->nprint( template => '/path/to/template',
-                 lookups  => [ \%special_hash, 'My::lookups'] ) ;
+                 lookups  => [ \%special_hash, 'My::lookups'],
+                 container_template => '/path/to/container_template') ;
 
 =head2 ID_list ( [identation_string [, end_marker]] )
 
@@ -1002,8 +1000,6 @@ You shouldn't need to use this method unless you want to build the cache in adva
 
 Template::Magic opens and parses a template file only the first time or if the file has been modified. Since the template caching is automatic you shouldn't need to use this method under normal situations, anyway with this method you can purge the I<template_path> from the cache. Without any I<template_path> parameter the method purges all the stored templates.
 
-B<Note>: I<template_path> must be an absolute path.
-
 =head2 find_file ( template )
 
 This method is internally used to find the templates you pass with C<print(), nprint(), output(), noutput()> methods or an 'INCLUDE_TEMPLATE' label (and its relative Zone method C<include_template>).
@@ -1515,6 +1511,12 @@ Control the caching of the templates structures. 'cache' is the default, so you
 
 =back
 
+=head3 container_template
+
+You can pass a generic template which will be used as a sort of frame for all the printed templates. It can be set to one I<template> parameter that can be a reference to a SCALAR content, a path to a template file or a filehandle.
+
+(See L<"Surrounding the output with a container template">)
+
 =head3 Constants
 
 If you write your own handler you can find useful a couple of constants that you can import:
@@ -1637,7 +1639,7 @@ To include a file in a template use the I<INCLUDE_TEMPLATE> label passing the fi
 
 The  F<'/temp/footer.html'> file will be included in place of the label and it will be processed (and automatically cached) as usual.
 
-B<WARNING>: An icluded template is processed as it was a complete template, this means that a I<block> should be always ended with an I<end label> in the same template. In other words I<blocks> cannot cross the phisical boundary of the file they belong to, or unpredictable behaviours could occur.
+B<WARNING>: An icluded template is processed as it was a complete template, this means that a I<block> should be always ended with an I<end label> in the same template. In other words I<blocks> cannot cross the boundary of the file they belong to, or unpredictable behaviours could occur.
 
 =head2 Conditionally include and process a template file
 
@@ -1660,6 +1662,38 @@ The template:
 
     this is the template {include_if_some_condition} end template
 
+=head2 Surrounding the output with a container template
+
+Sometime you may have headers and footers to add to a single or all the templates you want to print. You can use the 'container_template' argument, to pass the container template to the object constructor or to the C<noutput>  or C<nprint> methods:
+
+    # will work with all the outputs
+    $tm = new Template::Magic
+              container_template => '/path/to/container_template';
+    
+    $tm->print('/path/to/template');
+    
+    # will work just for a single output
+    $tm = new Template::Magic
+    
+    $tm->nprint(container_template => '/path/to/container_template',
+               template => '/path/to/template' );
+
+The container template file is a regular template, but MUST include an INCLUDE_TEMPLATE label B<without any attribute>: the original template will be used as the included template:
+
+   An header
+   {INCLUDE_TEMPLATE}
+   a footer
+
+The template file:
+
+   The template content
+
+The output:
+
+   An header
+   The template content
+   a footer
+
 =head2 Include (huge) text files without memory charges
 
 To include in the output a (probably huge) text file, without having to keep it in memory as a template, and without any other parsing, add the L<INCLUDE_TEXT> I<zone handler> and add a label with the I<zone identifier> equal to 'INCLUDE_TEXT' and the I<zone attributes> equal to the file path to include.
@@ -2599,7 +2633,7 @@ L<http://lists.sourceforge.net/lists/listinfo/template-magic-users>
 
 =head1 AUTHOR and COPYRIGHT
 
- 2004 by Domizio Demichelis (L<http://perl.4pro.net>)
+ 2004-2005 by Domizio Demichelis (L<http://perl.4pro.net>)
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
 
